@@ -121,8 +121,8 @@
 
     cc <- function(x, y) {
       if (dsp == "t") {
-        x <- (as.real(x) - 1)/iw
-        y <- 1 - (as.real(y) - 1)/ih
+        x <- (as.double(x) - 1)/iw
+        y <- 1 - (as.double(y) - 1)/ih
       }
       px <- (x - get("cplt", envir=e1)[1])/(get("cplt", envir=e1)[2] - get("cplt", envir=e1)[1])
       py <- (y - get("cplt", envir=e1)[3])/(get("cplt", envir=e1)[4] - get("cplt", envir=e1)[3])
